@@ -1,34 +1,58 @@
 """file.py."""
+
 import os
-from dataclasses import dataclass
 from datetime import datetime, timezone
 from pathlib import Path
-from typing import Optional, Tuple
+from typing import Any, Optional, Tuple
+
+from strangeworks_core.platform.gql import Operation
+from strangeworks_core.types.file import File as FileBase
 
-from strangeworks.core.client.platform import API, Operation
 from strangeworks.core.errors.error import StrangeworksError
+from strangeworks.platform.gql import SDKAPI
 
 
-@dataclass
-class File:
-    """Class representing a file."""
+class File(FileBase, arbitrary_types_allowed=True):
+    """Class representing files on the platform for SDK users.
 
-    id: str
-    slug: str
-    label: Optional[str] = None
-    file_name: Optional[str] = None
-    url: Optional[str] = None
+    Attributes
+    ----------
+    content: any | None
+        Content of the file. Defaults to None.
+    data_schema_slug: str | None
+        Optional data schema slug. Defaults to None.
+    """
+
+    content: Any = None
+    data_schema_slug: str | None = None
+    local_path: Path | None = None
 
     @classmethod
-    def from_dict(cls, d: dict):
-        """Generate a File object from a dictionary."""
-        return File(
-            id=d.get("id"),
-            slug=d.get("slug"),
-            label=d.get("label", None),
-            file_name=d.get("fileName", None),
-            url=d.get("url", None),
-        )
+    def from_dict(cls, data: dict) -> "File":
+        """Generate File object from dictionary.
+
+        Parameters
+        ----------
+        data: dict
+            File object represented as a dictionary.
+
+        Returns
+        -------
+        : File
+            File object.
+        """
+        return File(**data)
+
+    @property
+    def id(self) -> str:
+        """Retrieve File ID.
+
+        This is an internal identifier used by the platform and should only be used for
+        debugging, etc.
+
+        Added for backward compatibility.
+        """
+        return self.file_id
 
 
 _upload_file_request = Operation(
@@ -75,7 +99,7 @@ _upload_file_request = Operation(
 
 
 def upload(
-    client: API,
+    client: SDKAPI,
     workspace_slug: str,
     path: str,
     is_public: bool = False,
