@@ -7,7 +7,9 @@ from typing import Any, Dict, Optional
 import requests
 
 from strangeworks.core.client import auth
+from strangeworks.core.config import config
 from strangeworks.core.errors.error import StrangeworksError
+from strangeworks.core.utils import is_empty_str
 
 
 class StrangeworksRestClient:
@@ -99,6 +101,7 @@ class StrangeworksRestClient:
         self.__session.headers.update(self.headers)
         # set up re-authentication hook!
         self.__session.hooks["response"].append(self.__reauthenticate)
+        self.__cfg = config.Config()
 
     def _refresh_token(self) -> None:
         self.__auth_token = auth.get_token(self.api_key, self.host)
@@ -157,7 +160,11 @@ class StrangeworksRestClient:
         --------
         requests.request
         """
+        exp_trial_id = self.__cfg.get("experiment_trial_id", profile="default")
+        if exp_trial_id and not is_empty_str(exp_trial_id):
+            self.headers["x-strangeworks-experiment-trial-id"] = exp_trial_id
         self.__session.headers.update(self.headers)
+        self.__session.headers["content-type"] = "application/json"
         r = self.__session.post(
             url=f"{self.host}{url}",
             json=json,
@@ -219,6 +226,21 @@ class StrangeworksRestClient:
         return res
 
     def put(self, url: str, data=None, **kwargs) -> requests.Response:
+        """Use the session to issue a PUT.
+
+        Parameters
+        ----------
+        url : str
+            The URL to perform the PUT request.
+        data : Optional[Dict[str, Any]]
+            Payload to send with request. See requests put function documentation for
+            more details.
+
+        Returns
+        -------
+        res : requests.Response
+            The response object from ``requests``.
+        """
         self.__session.headers.update(self.headers)
         self.__session.headers["content-type"] = "application/x-www-form-urlencoded"
         r = self.__session.put(url, data=data, **kwargs)
