@@ -1,7 +1,7 @@
 """defaults.py."""
 from typing import Optional
 
-from strangeworks.core.config.base import ConfigSource
+from strangeworks.core.config.base import DEFAULT_PROFILE_NAME, ConfigSource
 
 DEFAULT_URL = "https://api.strangeworks.com"
 
@@ -11,17 +11,19 @@ class DefaultConfig(ConfigSource):
 
     cfg = {"url": DEFAULT_URL}
 
-    def get(self, key: str, profile: str = "default") -> Optional[str]:
-        """Strangeworks SDK Default Configurations
+    def get(self, key: str, profile: str = DEFAULT_PROFILE_NAME) -> Optional[str]:
+        """Strangeworks SDK Default Configurations.
 
         Serves as a source of default config values.  Any request for a profile other
         than default will return None.
         """
-        if profile != "default" or key not in DefaultConfig.cfg:
+        if profile != DEFAULT_PROFILE_NAME or key not in DefaultConfig.cfg:
             return None
 
-        return DefaultConfig.cfg[key]
+        return DefaultConfig.cfg.get(key)
 
-    def set(self, profile: str = "default", overwrite: bool = False, **params):
+    def set(
+        self, profile: str = DEFAULT_PROFILE_NAME, overwrite: bool = False, **params
+    ):
         """Set (no-op) for default profile."""
         return
